@@ -1,12 +1,11 @@
 /*
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * Copyright 2020-2021 Devin Lin <devin@kde.org>
  * Copyright 2021 Boris Petrov <boris.v.petrov@protonmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef KCLOCK_TIMERMODEL_H
-#define KCLOCK_TIMERMODEL_H
+#pragma once
 
 #include <QObject>
 
@@ -18,17 +17,14 @@ class TimerModel : public QObject
     Q_CLASSINFO("D-Bus Interface", "org.kde.kclock.TimerModel")
 
 public:
-    static TimerModel *instance()
-    {
-        static TimerModel *singleton = new TimerModel();
-        return singleton;
-    }
+    static TimerModel *instance();
 
     void load();
     void save();
     Q_SCRIPTABLE QStringList timers() const;
     Q_SCRIPTABLE void addTimer(int length, QString label, QString commandTimeout, bool running);
     Q_SCRIPTABLE void removeTimer(QString uuid);
+
 Q_SIGNALS:
     Q_SCRIPTABLE void timerAdded(QString);
     Q_SCRIPTABLE void timerRemoved(QString);
@@ -40,5 +36,3 @@ private:
 
     QList<Timer *> m_timerList;
 };
-
-#endif // KCLOCK_TIMERMODEL_H
